@@ -33,7 +33,7 @@ static inline int RGB2BGR(int c)
 /* However bswap is not supported by 386 */
 
     if (MODEFLAGS & MODEFLAG_24BPP_REVERSED)
-#ifdef NO_ASSEMBLY
+#ifdef __alpha__
 	c = ((c >> 0) & 0xff) << 16 |
 	    ((c >> 8) & 0xff) << 8 |
 	    ((c >> 16) & 0xff) << 0;
@@ -78,14 +78,14 @@ static void notimplemented(char *s)
 #define ASSIGNVP8(x, y, vp) vp = VBUF + (y) * BYTEWIDTH + (x);
 #define ASSIGNVPOFFSET8(x, y, vp) vp = (y) * BYTEWIDTH + (x);
 
-void __svgalib_driver8_setpixel(int x, int y, int c)
+void driver8_setpixel(int x, int y, int c)
 {
     char *vp;
     ASSIGNVP8(x, y, vp);
     *vp = c;
 }
 
-void __svgalib_driver8p_setpixel(int x, int y, int c)
+void driver8p_setpixel(int x, int y, int c)
 {
     int vp;
     ASSIGNVPOFFSET8(x, y, vp);
@@ -93,14 +93,14 @@ void __svgalib_driver8p_setpixel(int x, int y, int c)
     *(VBUF + (vp & 0xffff)) = c;
 }
 
-int __svgalib_driver8_getpixel(int x, int y)
+int driver8_getpixel(int x, int y)
 {
     char *vp;
     ASSIGNVP8(x, y, vp);
     return *vp;
 }
 
-int __svgalib_driver8p_getpixel(int x, int y)
+int driver8p_getpixel(int x, int y)
 {
     int vp;
     ASSIGNVPOFFSET8(x, y, vp);
@@ -108,14 +108,14 @@ int __svgalib_driver8p_getpixel(int x, int y)
     return *(VBUF + (vp & 0xffff));
 }
 
-void __svgalib_driver8_hline(int x1, int y, int x2, int c)
+void driver8_hline(int x1, int y, int x2, int c)
 {
     char *vp;
     ASSIGNVP8(x1, y, vp);
     __memset(vp, c, x2 - x1 + 1);
 }
 
-void __svgalib_driver8p_hline(int x1, int y, int x2, int c)
+void driver8p_hline(int x1, int y, int x2, int c)
 {
     int vp;
     char *rvp;
@@ -133,7 +133,7 @@ void __svgalib_driver8p_hline(int x1, int y, int x2, int c)
     }
 }
 
-void __svgalib_driver8_fillbox(int x, int y, int w, int h, int c)
+void driver8_fillbox(int x, int y, int w, int h, int c)
 {
     char *vp;
     int i;
@@ -144,17 +144,20 @@ void __svgalib_driver8_fillbox(int x, int y, int w, int h, int c)
     }
 }
 
-void __svgalib_driver8a_fillbox(int x, int y, int w, int h, int c)
+void driver8a_fillbox(int x, int y, int w, int h, int c)
 {
     if (w * h < 128)
-	(*__svgalib_nonaccel_fillbox)(x, y, w, h, c);
+	if (MODETYPE == CONTEXT_LINEAR)
+	    driver8_fillbox(x, y, w, h, c);
+	else
+	    driver8p_fillbox(x, y, w, h, c);
     else {
 	vga_accel(ACCEL_SETFGCOLOR, c);
 	vga_accel(ACCEL_FILLBOX, x, y, w, h);
     }
 }
 
-void __svgalib_driver8p_fillbox(int x, int y, int w, int h, int c)
+void driver8p_fillbox(int x, int y, int w, int h, int c)
 {
     int vp;
     int page;
@@ -164,7 +167,7 @@ void __svgalib_driver8p_fillbox(int x, int y, int w, int h, int c)
     vp &= 0xffff;
     vga_setpage(page);
     for (i = 0; i < h; i++) {
-	if (vp + w > 0x10000) {
+	if (vp + w > 0x10000)
 	    if (vp >= 0x10000) {
 		page++;
 		vga_setpage(page);
@@ -177,13 +180,12 @@ void __svgalib_driver8p_fillbox(int x, int y, int w, int h, int c)
 		vp = (vp + BYTEWIDTH) & 0xffff;
 		continue;
 	    }
-        };
 	__memset(VBUF + vp, c, w);
 	vp += BYTEWIDTH;
     }
 }
 
-void __svgalib_driver8_putbox(int x, int y, int w, int h, void *b, int bw)
+void driver8_putbox(int x, int y, int w, int h, void *b, int bw)
 {
     char *vp;			/* screen pointer */
     char *bp;			/* bitmap pointer */
@@ -197,7 +199,7 @@ void __svgalib_driver8_putbox(int x, int y, int w, int h, void *b, int bw)
     }
 }
 
-void __svgalib_driver8p_putbox(int x, int y, int w, int h, void *b, int bw)
+void driver8p_putbox(int x, int y, int w, int h, void *b, int bw)
 {
 /* extra argument width of source bitmap, so that putboxpart can use this */
     int vp;
@@ -209,7 +211,7 @@ void __svgalib_driver8p_putbox(int x, int y, int w, int h, void *b, int bw)
     vp &= 0xffff;
     vga_setpage(page);
     for (i = 0; i < h; i++) {
-	if (vp + w > 0x10000) {
+	if (vp + w > 0x10000)
 	    if (vp >= 0x10000) {
 		page++;
 		vga_setpage(page);
@@ -224,14 +226,13 @@ void __svgalib_driver8p_putbox(int x, int y, int w, int h, void *b, int bw)
 		bp += bw;
 		continue;
 	    }
-        };
 	__memcpy(VBUF + vp, bp, w);
 	bp += bw;
 	vp += BYTEWIDTH;
     }
 }
 
-void __svgalib_driver8_getbox(int x, int y, int w, int h, void *b, int bw)
+void driver8_getbox(int x, int y, int w, int h, void *b, int bw)
 {
     char *vp;			/* screen pointer */
     char *bp;			/* bitmap pointer */
@@ -245,7 +246,7 @@ void __svgalib_driver8_getbox(int x, int y, int w, int h, void *b, int bw)
     }
 }
 
-void __svgalib_driver8p_getbox(int x, int y, int w, int h, void *b, int bw)
+void driver8p_getbox(int x, int y, int w, int h, void *b, int bw)
 {
     int vp;
     int page;
@@ -256,7 +257,7 @@ void __svgalib_driver8p_getbox(int x, int y, int w, int h, void *b, int bw)
     vp &= 0xffff;
     vga_setpage(page);
     for (i = 0; i < h; i++) {
-	if (vp + w > 0x10000) {
+	if (vp + w > 0x10000)
 	    if (vp >= 0x10000) {
 		page++;
 		vga_setpage(page);
@@ -271,14 +272,13 @@ void __svgalib_driver8p_getbox(int x, int y, int w, int h, void *b, int bw)
 		bp += bw;
 		continue;
 	    }
-        };
 	__memcpy(bp, VBUF + vp, w);
 	bp += bw;
 	vp += BYTEWIDTH;
     }
 }
 
-void __svgalib_driver8_putboxmask(int x, int y, int w, int h, void *b)
+void driver8_putboxmask(int x, int y, int w, int h, void *b)
 {
     uchar *bp = b;
     uchar *vp;
@@ -313,31 +313,31 @@ void __svgalib_driver8_putboxmask(int x, int y, int w, int h, void *b)
     }
 }
 
-void __svgalib_driver8_putboxpart(int x, int y, int w, int h, int ow, int oh,
+void driver8_putboxpart(int x, int y, int w, int h, int ow, int oh,
 			void *b, int xo, int yo)
 {
-    __svgalib_driver8_putbox(x, y, w, h, b + yo * ow + xo, ow);	/* inlined */
+    driver8_putbox(x, y, w, h, b + yo * ow + xo, ow);	/* inlined */
 }
 
-void __svgalib_driver8p_putboxpart(int x, int y, int w, int h, int ow, int oh,
+void driver8p_putboxpart(int x, int y, int w, int h, int ow, int oh,
 			 void *b, int xo, int yo)
 {
-    __svgalib_driver8p_putbox(x, y, w, h, b + yo * ow + xo, ow);	/* inlined */
+    driver8p_putbox(x, y, w, h, b + yo * ow + xo, ow);	/* inlined */
 }
 
-void __svgalib_driver8_getboxpart(int x, int y, int w, int h, int ow, int oh,
+void driver8_getboxpart(int x, int y, int w, int h, int ow, int oh,
 			void *b, int xo, int yo)
 {
-    __svgalib_driver8_getbox(x, y, w, h, b + yo * ow + xo, ow);
+    driver8_getbox(x, y, w, h, b + yo * ow + xo, ow);
 }
 
-void __svgalib_driver8p_getboxpart(int x, int y, int w, int h, int ow, int oh,
+void driver8p_getboxpart(int x, int y, int w, int h, int ow, int oh,
 			 void *b, int xo, int yo)
 {
-    __svgalib_driver8p_getbox(x, y, w, h, b + yo * ow + xo, ow);
+    driver8p_getbox(x, y, w, h, b + yo * ow + xo, ow);
 }
 
-void __svgalib_driver8_copybox(int x1, int y1, int w, int h, int x2, int y2)
+void driver8_copybox(int x1, int y1, int w, int h, int x2, int y2)
 {
     char *svp, *dvp;
     /* I hope this works now. */
@@ -379,7 +379,7 @@ void __svgalib_driver8_copybox(int x1, int y1, int w, int h, int x2, int y2)
     }
 }
 
-void __svgalib_driver8a_copybox(int x1, int y1, int w, int h, int x2, int y2)
+void driver8a_copybox(int x1, int y1, int w, int h, int x2, int y2)
 {
     vga_accel(ACCEL_SCREENCOPY, x1, y1, x2, y2, w, h);
 }
@@ -391,14 +391,14 @@ void __svgalib_driver8a_copybox(int x1, int y1, int w, int h, int x2, int y2)
 #define ASSIGNVP16(x, y, vp) vp = VBUF + (y) * BYTEWIDTH + (x) * 2;
 #define ASSIGNVPOFFSET16(x, y, vp) vp = (y) * BYTEWIDTH + (x) * 2;
 
-void __svgalib_driver16_setpixel(int x, int y, int c)
+void driver16_setpixel(int x, int y, int c)
 {
     char *vp;
     ASSIGNVP16(x, y, vp);
     *(unsigned short *) vp = c;
 }
 
-void __svgalib_driver16p_setpixel(int x, int y, int c)
+void driver16p_setpixel(int x, int y, int c)
 {
     int vp;
     ASSIGNVPOFFSET16(x, y, vp);
@@ -406,14 +406,14 @@ void __svgalib_driver16p_setpixel(int x, int y, int c)
     *(unsigned short *) (VBUF + (vp & 0xffff)) = c;
 }
 
-int __svgalib_driver16_getpixel(int x, int y)
+int driver16_getpixel(int x, int y)
 {
     char *vp;
     ASSIGNVP16(x, y, vp);
     return *(unsigned short *) vp;
 }
 
-int __svgalib_driver16p_getpixel(int x, int y)
+int driver16p_getpixel(int x, int y)
 {
     int vp;
     ASSIGNVPOFFSET16(x, y, vp);
@@ -421,14 +421,14 @@ int __svgalib_driver16p_getpixel(int x, int y)
     return *(unsigned short *) (VBUF + (vp & 0xffff));
 }
 
-void __svgalib_driver16_hline(int x1, int y, int x2, int c)
+void driver16_hline(int x1, int y, int x2, int c)
 {
     char *vp;
     ASSIGNVP16(x1, y, vp);
     __memset2(vp, c, x2 - x1 + 1);
 }
 
-void __svgalib_driver16p_hline(int x1, int y, int x2, int c)
+void driver16p_hline(int x1, int y, int x2, int c)
 {
     int vp;
     char *rvp;
@@ -446,7 +446,7 @@ void __svgalib_driver16p_hline(int x1, int y, int x2, int c)
     }
 }
 
-void __svgalib_driver16_fillbox(int x, int y, int w, int h, int c)
+void driver16_fillbox(int x, int y, int w, int h, int c)
 {
     char *vp;
     int i;
@@ -457,7 +457,7 @@ void __svgalib_driver16_fillbox(int x, int y, int w, int h, int c)
     }
 }
 
-void __svgalib_driver16p_fillbox(int x, int y, int w, int h, int c)
+void driver16p_fillbox(int x, int y, int w, int h, int c)
 {
     int vp;
     int page;
@@ -467,7 +467,7 @@ void __svgalib_driver16p_fillbox(int x, int y, int w, int h, int c)
     vp &= 0xffff;
     vga_setpage(page);
     for (i = 0; i < h; i++) {
-	if (vp + w * 2 > 0x10000) {
+	if (vp + w * 2 > 0x10000)
 	    if (vp >= 0x10000) {
 		page++;
 		vga_setpage(page);
@@ -480,13 +480,12 @@ void __svgalib_driver16p_fillbox(int x, int y, int w, int h, int c)
 		vp = (vp + BYTEWIDTH) & 0xffff;
 		continue;
 	    }
-        };
 	__memset2(VBUF + vp, c, w);
 	vp += BYTEWIDTH;
     }
 }
 
-void __svgalib_driver16_putbox(int x, int y, int w, int h, void *b, int bw)
+void driver16_putbox(int x, int y, int w, int h, void *b, int bw)
 {
     char *vp;			/* screen pointer */
     char *bp;			/* bitmap pointer */
@@ -500,12 +499,12 @@ void __svgalib_driver16_putbox(int x, int y, int w, int h, void *b, int bw)
     }
 }
 
-void __svgalib_driver16p_putbox(int x, int y, int w, int h, void *b, int bw)
+void driver16p_putbox(int x, int y, int w, int h, void *b, int bw)
 {
-    __svgalib_driver8p_putbox(x * 2, y, w * 2, h, b, bw * 2);
+    driver8p_putbox(x * 2, y, w * 2, h, b, bw * 2);
 }
 
-void __svgalib_driver16_getbox(int x, int y, int w, int h, void *b, int bw)
+void driver16_getbox(int x, int y, int w, int h, void *b, int bw)
 {
     char *vp;			/* screen pointer */
     char *bp;			/* bitmap pointer */
@@ -519,12 +518,12 @@ void __svgalib_driver16_getbox(int x, int y, int w, int h, void *b, int bw)
     }
 }
 
-INLINE void __svgalib_driver16p_getbox(int x, int y, int w, int h, void *b, int bw)
+INLINE void driver16p_getbox(int x, int y, int w, int h, void *b, int bw)
 {
-    __svgalib_driver8p_getbox(x * 2, y, w * 2, h, b, bw * 2);
+    driver8p_getbox(x * 2, y, w * 2, h, b, bw * 2);
 }
 
-void __svgalib_driver16_putboxmask(int x, int y, int w, int h, void *b)
+void driver16_putboxmask(int x, int y, int w, int h, void *b)
 {
     uchar *bp = b;
     uchar *vp;
@@ -559,37 +558,37 @@ void __svgalib_driver16_putboxmask(int x, int y, int w, int h, void *b)
     }
 }
 
-INLINE void __svgalib_driver16_putboxpart(int x, int y, int w, int h, int ow, int oh,
+INLINE void driver16_putboxpart(int x, int y, int w, int h, int ow, int oh,
 				void *b, int xo, int yo)
 {
-    __svgalib_driver8_putbox(x * 2, y, w * 2, h, b + yo * ow * 2 + xo * 2, ow * 2);
+    driver8_putbox(x * 2, y, w * 2, h, b + yo * ow * 2 + xo * 2, ow * 2);
     /* inlined */
 }
 
-INLINE void __svgalib_driver16p_putboxpart(int x, int y, int w, int h, int ow, int oh,
+INLINE void driver16p_putboxpart(int x, int y, int w, int h, int ow, int oh,
 				 void *b, int xo, int yo)
 {
-    __svgalib_driver8p_putbox(x * 2, y, w * 2, h, b + yo * ow * 2 + xo * 2, ow * 2);
+    driver8p_putbox(x * 2, y, w * 2, h, b + yo * ow * 2 + xo * 2, ow * 2);
 }
 
-INLINE void __svgalib_driver16_getboxpart(int x, int y, int w, int h, int ow, int oh,
+INLINE void driver16_getboxpart(int x, int y, int w, int h, int ow, int oh,
 				void *b, int xo, int yo)
 {
-    __svgalib_driver16_getbox(x, y, w, h, b + yo * ow + xo, ow);
+    driver16_getbox(x, y, w, h, b + yo * ow + xo, ow);
 }
 
-INLINE void __svgalib_driver16p_getboxpart(int x, int y, int w, int h, int ow, int oh,
+INLINE void driver16p_getboxpart(int x, int y, int w, int h, int ow, int oh,
 				 void *b, int xo, int yo)
 {
-    __svgalib_driver16p_getbox(x, y, w, h, b + yo * ow + xo, ow);
+    driver16p_getbox(x, y, w, h, b + yo * ow + xo, ow);
 }
 
-INLINE void __svgalib_driver16_copybox(int x1, int y1, int w, int h, int x2, int y2)
+INLINE void driver16_copybox(int x1, int y1, int w, int h, int x2, int y2)
 {
-    __svgalib_driver8_copybox(x1 * 2, y1, w * 2, h, x2 * 2, y2);
+    driver8_copybox(x1 * 2, y1, w * 2, h, x2 * 2, y2);
 }
 
-void __svgalib_driver16a_copybox(int x1, int y1, int w, int h, int x2, int y2)
+void driver16a_copybox(int x1, int y1, int w, int h, int x2, int y2)
 {
     int svp, dvp;
     ASSIGNVPOFFSET16(x1, y1, svp);
@@ -606,7 +605,7 @@ void __svgalib_driver16a_copybox(int x1, int y1, int w, int h, int x2, int y2)
 #define RGBEQUAL(c) ((c & 0xff) == ((c >> 8) & 0xff) && \
 	(c & 0xff) == ((c >> 16) & 0xff))
 
-void __svgalib_driver24_setpixel(int x, int y, int c)
+void driver24_setpixel(int x, int y, int c)
 {
     char *vp;
     c = RGB2BGR(c);
@@ -615,7 +614,7 @@ void __svgalib_driver24_setpixel(int x, int y, int c)
     *(unsigned char *) (vp + 2) = c >> 16;
 }
 
-void __svgalib_driver24p_setpixel(int x, int y, int c)
+void driver24p_setpixel(int x, int y, int c)
 {
     int vp, vpo;
     char *vbuf;
@@ -640,14 +639,14 @@ void __svgalib_driver24p_setpixel(int x, int y, int c)
     }
 }
 
-int __svgalib_driver24_getpixel(int x, int y)
+int driver24_getpixel(int x, int y)
 {
     char *vp;
     ASSIGNVP24(x, y, vp);
     return RGB2BGR(*(unsigned short *) vp + (*(unsigned char *) (vp + 2) << 16));
 }
 
-int __svgalib_driver24p_getpixel(int x, int y)
+int driver24p_getpixel(int x, int y)
 {
     int vp, vpo;
     char *vbuf;
@@ -673,7 +672,7 @@ int __svgalib_driver24p_getpixel(int x, int y)
     }
 }
 
-void __svgalib_driver24_hline(int x1, int y, int x2, int c)
+void driver24_hline(int x1, int y, int x2, int c)
 {
     char *vp;
     c = RGB2BGR(c);
@@ -684,7 +683,7 @@ void __svgalib_driver24_hline(int x1, int y, int x2, int c)
 	__memset3(vp, c, x2 - x1 + 1);
 }
 
-void __svgalib_driver24p_hline(int x1, int y, int x2, int c)
+void driver24p_hline(int x1, int y, int x2, int c)
 {
     int vp;
     char *rvp;
@@ -720,7 +719,7 @@ void __svgalib_driver24p_hline(int x1, int y, int x2, int c)
     }
 }
 
-void __svgalib_driver24_fillbox(int x, int y, int w, int h, int c)
+void driver24_fillbox(int x, int y, int w, int h, int c)
 {
     char *vp;
     int i, j;
@@ -737,7 +736,7 @@ void __svgalib_driver24_fillbox(int x, int y, int w, int h, int c)
 	}
 }
 
-void __svgalib_driver24p_fillbox(int x, int y, int w, int h, int c)
+void driver24p_fillbox(int x, int y, int w, int h, int c)
 {
     int vp;
     int page;
@@ -749,7 +748,7 @@ void __svgalib_driver24p_fillbox(int x, int y, int w, int h, int c)
     vga_setpage(page);
     if (RGBEQUAL(c)) {
 	for (i = 0; i < h; i++) {
-	    if (vp + w * 3 > 0x10000) {
+	    if (vp + w * 3 > 0x10000)
 		if (vp >= 0x10000) {
 		    page++;
 		    vga_setpage(page);
@@ -762,13 +761,12 @@ void __svgalib_driver24p_fillbox(int x, int y, int w, int h, int c)
 		    vp = (vp + BYTEWIDTH) & 0xffff;
 		    continue;
 		}
-            };
 	    __memset(VBUF + vp, c, w * 3);
 	    vp += BYTEWIDTH;
 	}
     } else
 	for (i = 0; i < h; i++) {
-	    if (vp + w * 3 > 0x10000) {
+	    if (vp + w * 3 > 0x10000)
 		if (vp >= 0x10000) {
 		    page++;
 		    vga_setpage(page);
@@ -798,13 +796,12 @@ void __svgalib_driver24p_fillbox(int x, int y, int w, int h, int c)
 		    vp = (vp + BYTEWIDTH) & 0xffff;
 		    continue;
 		}
-            };
 	    __memset3(VBUF + vp, c, w);
 	    vp += BYTEWIDTH;
 	}
 }
 
-void __svgalib_driver24_putbox(int x, int y, int w, int h, void *b, int bw)
+void driver24_putbox(int x, int y, int w, int h, void *b, int bw)
 {
     char *vp;			/* screen pointer */
     char *bp;			/* bitmap pointer */
@@ -839,7 +836,7 @@ static void driver24_rev_putbox(int x, int y, int w, int h, void *b, int bw)
     vp &= 0xffff;
     vga_setpage(page);
     for (i = 0; i < h; i++) {
-	if (vp + w > 0x10000) {
+	if (vp + w > 0x10000)
 	    if (vp >= 0x10000) {
 		page++;
 		vga_setpage(page);
@@ -879,23 +876,22 @@ static void driver24_rev_putbox(int x, int y, int w, int h, void *b, int bw)
 		bp += bw;
 		continue;
 	    }
-        };
 	RGB_swapped_memcpy(VBUF + vp, bp, w);
 	bp += bw;
 	vp += BYTEWIDTH;
     }
 }
 
-INLINE void __svgalib_driver24p_putbox(int x, int y, int w, int h, void *b, int bw)
+INLINE void driver24p_putbox(int x, int y, int w, int h, void *b, int bw)
 {
     if (MODEFLAGS & MODEFLAG_24BPP_REVERSED) {
 	driver24_rev_putbox(x * 3, y, w * 3, h, b, bw * 3);
     } else {
-	__svgalib_driver8p_putbox(x * 3, y, w * 3, h, b, bw * 3);
+	driver8p_putbox(x * 3, y, w * 3, h, b, bw * 3);
     }
 }
 
-void __svgalib_driver24_putbox32(int x, int y, int w, int h, void *b, int bw)
+void driver24_putbox32(int x, int y, int w, int h, void *b, int bw)
 {
     char *vp;			/* screen pointer */
     char *bp;			/* bitmap pointer */
@@ -903,13 +899,13 @@ void __svgalib_driver24_putbox32(int x, int y, int w, int h, void *b, int bw)
     ASSIGNVP24(x, y, vp);
     bp = b;
     for (i = 0; i < h; i++) {
-	__svgalib_memcpy4to3(vp, bp, w);
+	memcpy4to3(vp, bp, w);
 	bp += bw * 4;
 	vp += BYTEWIDTH;
     }
 }
 
-void __svgalib_driver24_getbox(int x, int y, int w, int h, void *b, int bw)
+void driver24_getbox(int x, int y, int w, int h, void *b, int bw)
 {
     char *vp;			/* screen pointer */
     char *bp;			/* bitmap pointer */
@@ -944,7 +940,7 @@ static void driver24_rev_getbox(int x, int y, int w, int h, void *b, int bw)
     vp &= 0xffff;
     vga_setpage(page);
     for (i = 0; i < h; i++) {
-	if (vp + w > 0x10000) {
+	if (vp + w > 0x10000)
 	    if (vp >= 0x10000) {
 		page++;
 		vga_setpage(page);
@@ -984,23 +980,22 @@ static void driver24_rev_getbox(int x, int y, int w, int h, void *b, int bw)
 		bp += bw;
 		continue;
 	    }
-        };
 	RGB_swapped_memcpy(bp, VBUF + vp, w);
 	bp += bw;
 	vp += BYTEWIDTH;
     }
 }
 
-INLINE void __svgalib_driver24p_getbox(int x, int y, int w, int h, void *b, int bw)
+INLINE void driver24p_getbox(int x, int y, int w, int h, void *b, int bw)
 {
     if (MODEFLAGS & MODEFLAG_24BPP_REVERSED) {
 	driver24_rev_getbox(x * 3, y, w * 3, h, b, bw * 3);
     } else {
-	__svgalib_driver8p_getbox(x * 3, y, w * 3, h, b, bw * 3);
+	driver8p_getbox(x * 3, y, w * 3, h, b, bw * 3);
     }
 }
 
-void __svgalib_driver24_putboxmask(int x, int y, int w, int h, void *b)
+void driver24_putboxmask(int x, int y, int w, int h, void *b)
 {
     uchar *bp = b;
     uchar *vp;
@@ -1045,48 +1040,48 @@ void __svgalib_driver24_putboxmask(int x, int y, int w, int h, void *b)
     }
 }
 
-INLINE void __svgalib_driver24_putboxpart(int x, int y, int w, int h, int ow, int oh,
+INLINE void driver24_putboxpart(int x, int y, int w, int h, int ow, int oh,
 				void *b, int xo, int yo)
 {
     /*
-     * Actually I think all this could be done by just calling __svgalib_driver24_putbox
+     * Actually I think all this could be done by just calling driver24_putbox
      * with correct args. But I'm too fearful. - Michael.
      */
     if (MODEFLAGS & MODEFLAG_24BPP_REVERSED) {
-	__svgalib_driver24_putbox(x, y, w, h, b + yo * ow + xo, ow);
+	driver24_putbox(x, y, w, h, b + yo * ow + xo, ow);
     } else {
-	__svgalib_driver8_putbox(x * 3, y, w * 3, h, b + yo * ow * 3 + xo * 3, ow * 3);
+	driver8_putbox(x * 3, y, w * 3, h, b + yo * ow * 3 + xo * 3, ow * 3);
     }
 }
 
-INLINE void __svgalib_driver24p_putboxpart(int x, int y, int w, int h, int ow, int oh,
+INLINE void driver24p_putboxpart(int x, int y, int w, int h, int ow, int oh,
 				 void *b, int xo, int yo)
 {
     if (MODEFLAGS & MODEFLAG_24BPP_REVERSED) {
 	driver24_rev_putbox(x * 3, y, w * 3, h, b + yo * ow * 3 + xo * 3, ow * 3);
     } else {
-	__svgalib_driver8p_putbox(x * 3, y, w * 3, h, b + yo * ow * 3 + xo * 3, ow * 3);
+	driver8p_putbox(x * 3, y, w * 3, h, b + yo * ow * 3 + xo * 3, ow * 3);
     }
 }
 
-INLINE void __svgalib_driver24_getboxpart(int x, int y, int w, int h, int ow, int oh,
+INLINE void driver24_getboxpart(int x, int y, int w, int h, int ow, int oh,
 				void *b, int xo, int yo)
 {
-    __svgalib_driver24_getbox(x, y, w, h, b + yo * ow + xo, ow);
+    driver24_getbox(x, y, w, h, b + yo * ow + xo, ow);
 }
 
-INLINE void __svgalib_driver24p_getboxpart(int x, int y, int w, int h, int ow, int oh,
+INLINE void driver24p_getboxpart(int x, int y, int w, int h, int ow, int oh,
 				 void *b, int xo, int yo)
 {
-    __svgalib_driver24p_getbox(x, y, w, h, b + yo * ow + xo, ow);
+    driver24p_getbox(x, y, w, h, b + yo * ow + xo, ow);
 }
 
-void __svgalib_driver24_copybox(int x1, int y1, int w, int h, int x2, int y2)
+void driver24_copybox(int x1, int y1, int w, int h, int x2, int y2)
 {
-    __svgalib_driver8_copybox(x1 * 3, y1, w * 3, h, x2 * 3, y2);
+    driver8_copybox(x1 * 3, y1, w * 3, h, x2 * 3, y2);
 }
 
-void __svgalib_driver24a_copybox(int x1, int y1, int w, int h, int x2, int y2)
+void driver24a_copybox(int x1, int y1, int w, int h, int x2, int y2)
 {
     int svp, dvp;
     ASSIGNVPOFFSET24(x1, y1, svp);
@@ -1101,14 +1096,14 @@ void __svgalib_driver24a_copybox(int x1, int y1, int w, int h, int x2, int y2)
 #define ASSIGNVP32(x, y, vp) vp = VBUF + (y) * BYTEWIDTH + (x) * 4;
 #define ASSIGNVPOFFSET32(x, y, vp) vp = (y) * BYTEWIDTH + (x) * 4;
 
-void __svgalib_driver32_setpixel(int x, int y, int c)
+void driver32_setpixel(int x, int y, int c)
 {
     char *vp;
     ASSIGNVP32(x, y, vp);
     *(unsigned *) vp = c;
 }
 
-void __svgalib_driver32p_setpixel(int x, int y, int c)
+void driver32p_setpixel(int x, int y, int c)
 {
     int vp;
     ASSIGNVPOFFSET32(x, y, vp);
@@ -1116,14 +1111,14 @@ void __svgalib_driver32p_setpixel(int x, int y, int c)
     *(unsigned *) (VBUF + (vp & 0xffff)) = c;
 }
 
-int __svgalib_driver32_getpixel(int x, int y)
+int driver32_getpixel(int x, int y)
 {
     char *vp;
     ASSIGNVP32(x, y, vp);
     return *(unsigned *) vp;
 }
 
-int __svgalib_driver32p_getpixel(int x, int y)
+int driver32p_getpixel(int x, int y)
 {
     int vp;
     ASSIGNVPOFFSET32(x, y, vp);
@@ -1131,14 +1126,14 @@ int __svgalib_driver32p_getpixel(int x, int y)
     return *(unsigned *) (VBUF + (vp & 0xffff));
 }
 
-void __svgalib_driver32_hline(int x1, int y, int x2, int c)
+void driver32_hline(int x1, int y, int x2, int c)
 {
     char *vp;
     ASSIGNVP32(x1, y, vp);
     __memsetlong(vp, c, x2 - x1 + 1);
 }
 
-void __svgalib_driver32p_hline(int x1, int y, int x2, int c)
+void driver32p_hline(int x1, int y, int x2, int c)
 {
     int vp;
     char *rvp;
@@ -1156,7 +1151,7 @@ void __svgalib_driver32p_hline(int x1, int y, int x2, int c)
     }
 }
 
-void __svgalib_driver32_fillbox(int x, int y, int w, int h, int c)
+void driver32_fillbox(int x, int y, int w, int h, int c)
 {
     char *vp;
     int i;
@@ -1167,7 +1162,7 @@ void __svgalib_driver32_fillbox(int x, int y, int w, int h, int c)
     }
 }
 
-void __svgalib_driver32p_fillbox(int x, int y, int w, int h, int c)
+void driver32p_fillbox(int x, int y, int w, int h, int c)
 {
     int vp;
     int page;
@@ -1177,7 +1172,7 @@ void __svgalib_driver32p_fillbox(int x, int y, int w, int h, int c)
     vp &= 0xffff;
     vga_setpage(page);
     for (i = 0; i < h; i++) {
-	if (vp + w * 4 > 0x10000) {
+	if (vp + w * 4 > 0x10000)
 	    if (vp >= 0x10000) {
 		page++;
 		vga_setpage(page);
@@ -1190,33 +1185,32 @@ void __svgalib_driver32p_fillbox(int x, int y, int w, int h, int c)
 		vp = (vp + BYTEWIDTH) & 0xffff;
 		continue;
 	    }
-        };
 	__memsetlong(VBUF + vp, c, w);
 	vp += BYTEWIDTH;
     }
 }
 
-INLINE void __svgalib_driver32_putbox(int x, int y, int w, int h, void *b, int bw)
+INLINE void driver32_putbox(int x, int y, int w, int h, void *b, int bw)
 {
-    __svgalib_driver8_putbox(x * 4, y, w * 4, h, b, bw * 4);
+    driver8_putbox(x * 4, y, w * 4, h, b, bw * 4);
 }
 
-INLINE void __svgalib_driver32p_putbox(int x, int y, int w, int h, void *b, int bw)
+INLINE void driver32p_putbox(int x, int y, int w, int h, void *b, int bw)
 {
-    __svgalib_driver8p_putbox(x * 4, y, w * 4, h, b, bw * 4);
+    driver8p_putbox(x * 4, y, w * 4, h, b, bw * 4);
 }
 
-INLINE void __svgalib_driver32_getbox(int x, int y, int w, int h, void *b, int bw)
+INLINE void driver32_getbox(int x, int y, int w, int h, void *b, int bw)
 {
-    __svgalib_driver8_getbox(x * 4, y, w * 4, h, b, bw * 4);
+    driver8_getbox(x * 4, y, w * 4, h, b, bw * 4);
 }
 
-INLINE void __svgalib_driver32p_getbox(int x, int y, int w, int h, void *b, int bw)
+INLINE void driver32p_getbox(int x, int y, int w, int h, void *b, int bw)
 {
-    __svgalib_driver8p_getbox(x * 4, y, w * 4, h, b, bw * 4);
+    driver8p_getbox(x * 4, y, w * 4, h, b, bw * 4);
 }
 
-void __svgalib_driver32_putboxmask(int x, int y, int w, int h, void *b)
+void driver32_putboxmask(int x, int y, int w, int h, void *b)
 {
     uchar *bp = b;
     uchar *vp;
@@ -1251,55 +1245,55 @@ void __svgalib_driver32_putboxmask(int x, int y, int w, int h, void *b)
     }
 }
 
-INLINE void __svgalib_driver32_putboxpart(int x, int y, int w, int h, int ow, int oh,
+INLINE void driver32_putboxpart(int x, int y, int w, int h, int ow, int oh,
 				void *b, int xo, int yo)
 {
-    __svgalib_driver32_putbox(x, y, w, h, b + yo * ow * 4 + xo * 4 , ow );
+    driver32_putbox(x, y, w, h, b + yo * ow + xo, ow);
     /* inlined */
 }
 
-INLINE void __svgalib_driver32p_putboxpart(int x, int y, int w, int h, int ow, int oh,
+INLINE void driver32p_putboxpart(int x, int y, int w, int h, int ow, int oh,
 				 void *b, int xo, int yo)
 {
-    __svgalib_driver32p_putbox(x, y, w, h, b + yo * ow * 4 + xo * 4, ow );
+    driver32p_putbox(x, y, w, h, b + yo * ow + xo, ow);
     /* inlined */
 }
 
-INLINE void __svgalib_driver32_getboxpart(int x, int y, int w, int h, int ow, int oh,
+INLINE void driver32_getboxpart(int x, int y, int w, int h, int ow, int oh,
 				void *b, int xo, int yo)
 {
-    __svgalib_driver32_getbox(x, y, w, h, b + yo * ow * 4 + xo * 4 , ow );
+    driver32_getbox(x, y, w, h, b + yo * ow + xo, ow);
 }
 
-INLINE void __svgalib_driver32p_getboxpart(int x, int y, int w, int h, int ow, int oh,
+INLINE void driver32p_getboxpart(int x, int y, int w, int h, int ow, int oh,
 				 void *b, int xo, int yo)
 {
-    __svgalib_driver32p_getbox(x, y, w, h, b + yo * ow * 4 + xo * 4 , ow );
+    driver32p_getbox(x, y, w, h, b + yo * ow + xo, ow);
 }
 
-INLINE void __svgalib_driver32_copybox(int x1, int y1, int w, int h, int x2, int y2)
+INLINE void driver32_copybox(int x1, int y1, int w, int h, int x2, int y2)
 {
-    __svgalib_driver8_copybox(x1 * 4, y1, w * 4, h, x2 * 4, y2);
+    driver8_copybox(x1 * 4, y1, w * 4, h, x2 * 4, y2);
 }
 
 
 
 /* Planar 256 color mode graphics primitives (only putbox) */
 
-void __svgalib_driverplanar256_nothing(void)
+void driverplanar256_nothing(void)
 {
     NOTIMPL("planar 256 color mode primitive");
 }
 
-void __svgalib_driverplanar256_putbox(int x, int y, int w, int h, void *b, int bw)
+void driverplanar256_putbox(int x, int y, int w, int h, void *b, int bw)
 {
-    if ((w & 3) != 0 || (x & 3) != 0)
+    if (w & 3 != 0 || x & 3 != 0)
 	NOTIMPL("planar 256 color mode unaligned putbox");
     vga_copytoplanar256(b, bw, y * BYTEWIDTH + x / 4, BYTEWIDTH,
 			w, h);
 }
 
-void __svgalib_driverplanar16_nothing(void)
+void driverplanar16_nothing(void)
 {
     NOTIMPL("planar 16 color mode primitive");
 }
@@ -1307,7 +1301,7 @@ void __svgalib_driverplanar16_nothing(void)
 
 /* Memory primitives */
 
-int __svgalib_driver_setread(GraphicsContext * gc, int i, void **vp)
+int driver_setread(GraphicsContext * gc, int i, void **vp)
 {
     if (gc->modetype == CONTEXT_PAGED) {
 	vga_setpage(i >> 16);
@@ -1319,7 +1313,7 @@ int __svgalib_driver_setread(GraphicsContext * gc, int i, void **vp)
     }
 }
 
-int __svgalib_driver_setwrite(GraphicsContext * gc, int i, void **vp)
+int driver_setwrite(GraphicsContext * gc, int i, void **vp)
 {
     if (gc->modetype == CONTEXT_PAGED) {
 	vga_setpage(i >> 16);
@@ -1335,42 +1329,42 @@ int __svgalib_driver_setwrite(GraphicsContext * gc, int i, void **vp)
 
 /* Functions that are not yet implemented */
 
-void __svgalib_driver8p_putboxmask(int x, int y, int w, int h, void *b)
+void driver8p_putboxmask(int x, int y, int w, int h, void *b)
 {
     NOTIMPL("8-bit paged putboxmask");
 }
 
-void __svgalib_driver8p_copybox(int x1, int y1, int w, int h, int x2, int y2)
+void driver8p_copybox(int x1, int y1, int w, int h, int x2, int y2)
 {
     NOTIMPL("8-bit paged copybox (bitblt)");
 }
 
-void __svgalib_driver16p_putboxmask(int x, int y, int w, int h, void *b)
+void driver16p_putboxmask(int x, int y, int w, int h, void *b)
 {
     NOTIMPL("16-bit paged putboxmask");
 }
 
-void __svgalib_driver16p_copybox(int x1, int y1, int w, int h, int x2, int y2)
+void driver16p_copybox(int x1, int y1, int w, int h, int x2, int y2)
 {
     NOTIMPL("16-bit paged copybox");
 }
 
-void __svgalib_driver24p_putboxmask(int x, int y, int w, int h, void *b)
+void driver24p_putboxmask(int x, int y, int w, int h, void *b)
 {
     NOTIMPL("24-bit paged putboxmask");
 }
 
-void __svgalib_driver24p_copybox(int x1, int y1, int w, int h, int x2, int y2)
+void driver24p_copybox(int x1, int y1, int w, int h, int x2, int y2)
 {
     NOTIMPL("24-bit paged copybox");
 }
 
-void __svgalib_driver32p_putboxmask(int x, int y, int w, int h, void *b)
+void driver32p_putboxmask(int x, int y, int w, int h, void *b)
 {
     NOTIMPL("32-bit paged putboxmask");
 }
 
-void __svgalib_driver32p_copybox(int x1, int y1, int w, int h, int x2, int y2)
+void driver32p_copybox(int x1, int y1, int w, int h, int x2, int y2)
 {
     NOTIMPL("32-bit paged copybox");
 }
