@@ -10,7 +10,6 @@
 
 
 #include <stdio.h>
-#include <string.h>
 #include "vga.h"
 #include "libvga.h"
 #include "driver.h"
@@ -74,6 +73,11 @@ static ModeTable __ega_modes[] =
     OneModeEntry(640x350x16),
     END_OF_MODE_TABLE
 /* *INDENT-ON* */
+
+
+
+
+
 };
 
 static ModeTable *ega_modes = NULL;
@@ -123,7 +127,7 @@ static int saveregs(unsigned char *regs)
     else
 	r = LOOKUPMODE(ega_modes, lastmode);
     if (r == NULL) {
-	fprintf(stderr,"svgalib: egadrv.c/saveregs(): internal error\n");
+	printf("svgalib: egadrv.c/saveregs(): internal error\n");
 	exit(-1);
     }
     memcpy(regs, r, CRT_C + ATT_C + GRA_C + SEQ_C + MIS_C);
@@ -131,8 +135,8 @@ static int saveregs(unsigned char *regs)
     /* save all readable EGA registers; others are default */
     /* is this correct (even in graphics mode) ?? */
     for (i = 0x0C; i < 0x10; i++) {
-	port_out(i, __svgalib_CRT_I);
-	regs[CRT + i] = port_in(__svgalib_CRT_D);
+	port_out(i, CRT_I);
+	regs[CRT + i] = port_in(CRT_D);
     }
 
     return CRT_C + ATT_C + GRA_C + SEQ_C + MIS_C;
@@ -147,7 +151,7 @@ static void setregs(const unsigned char regs[], int mode)
     port_out(0x00, GRA_E0);
     port_out(0x01, GRA_E1);
 
-    __svgalib_setregs(regs);
+    __vga_setregs(regs);
 }
 
 /* Set a mode */
@@ -171,20 +175,20 @@ static int setmode(int mode, int prv_mode)
 
 static void setdisplaystart(int address)
 {
-    port_in(__svgalib_IS1_R);
-    __svgalib_delay();
+    inb(IS1_R);
+    __vga_delay();
     outb(ATT_IW, 0x13 + 0x20);
-    __svgalib_delay();
+    __vga_delay();
     outb(ATT_IW, (address & 7));
     /* write sa0-2 to bits 0-2 */
     address >>= 3;
-    outw(__svgalib_CRT_I, 0x0d + (address & 0x00ff) * 256);	/* sa0-sa7 */
-    outw(__svgalib_CRT_I, 0x0c + (address & 0xff00));	/* sa8-sa15 */
+    outw(CRT_I, 0x0d + (address & 0x00ff) * 256);	/* sa0-sa7 */
+    outw(CRT_I, 0x0c + (address & 0xff00));	/* sa8-sa15 */
 }
 
 static void setlogicalwidth(int width)
 {
-    outw(__svgalib_CRT_I, 0x13 + (width >> 3) * 256);	/* lw3-lw11 */
+    outw(CRT_I, 0x13 + (width >> 3) * 256);	/* lw3-lw11 */
 }
 
 
@@ -195,12 +199,12 @@ static int ega_test(void)
     unsigned char save, back;
 
     /* Check if a DAC is present */
-    save = port_in(PEL_IW);
-    __svgalib_delay();
+    save = inb(PEL_IW);
+    __vga_delay();
     outb(PEL_IW, ~save);
-    __svgalib_delay();
-    back = port_in(PEL_IW);
-    __svgalib_delay();
+    __vga_delay();
+    back = inb(PEL_IW);
+    __vga_delay();
     outb(PEL_IW, save);
     save = ~save;
     if (back != save) {
@@ -211,7 +215,7 @@ static int ega_test(void)
 }
 
 
-DriverSpecs __svgalib_ega_driverspecs =
+DriverSpecs ega_driverspecs =
 {				/* EGA */
     saveregs,
     setregs,
@@ -219,9 +223,9 @@ DriverSpecs __svgalib_ega_driverspecs =
     nothing /* lock */ ,
     ega_test,
     ega_init,
-    (void (*)(int)) nothing /* __svgalib_setpage */ ,
-    (void (*)(int)) nothing /* __svgalib_setrdpage */ ,
-    (void (*)(int)) nothing /* __svgalib_setwrpage */ ,
+    (void (*)(int)) nothing /* setpage */ ,
+    (void (*)(int)) nothing /* setrdpage */ ,
+    (void (*)(int)) nothing /* setwrpage */ ,
     setmode,
     modeavailable,
     setdisplaystart,
@@ -235,8 +239,7 @@ DriverSpecs __svgalib_ega_driverspecs =
     0,				/* extset */
     0,
     0,				/* linear */
-    NULL,                       /* Accelspecs */
-    NULL,                       /* Emulation */
+    NULL			/* accelspecs */
 };
 
 /* Initialize chipset (called after detection) */
@@ -245,7 +248,7 @@ static int ega_init(int force, int par1, int par2)
 {
 
     if (__svgalib_driver_report)
-	fprintf(stderr,"Using EGA driver.\n");
+	printf("Using EGA driver.\n");
 
     /* Read additional modes from file if available */
     if (ega_modes == NULL) {
@@ -255,16 +258,13 @@ static int ega_init(int force, int par1, int par2)
 	    FILE *regs;
 	    regs = fopen(EGA_REGS, "r");
 	    if (regs != 0) {
-		__svgalib_readmodes(regs, &ega_modes, NULL, NULL);
+		__vga_readmodes(regs, &ega_modes, NULL);
 		fclose(regs);
 	    }
 	}
 #endif
     }
-    __svgalib_driverspecs = &__svgalib_ega_driverspecs;
-
-    __svgalib_banked_mem_base=0xa0000;
-    __svgalib_banked_mem_size=0x10000;
+    driverspecs = &ega_driverspecs;
 
     return 0;
 }
