@@ -47,9 +47,14 @@ static ModeTable et3000_modes[] =
     OneModeEntry(1024x768x16),
     END_OF_MODE_TABLE
 /* *INDENT-ON* */
+
+
+
+
+
 };
 
-/*#endif *//* !defined(DYNAMIC) */
+																								      /*#endif *//* !defined(DYNAMIC) */
 
 /* Fill in chipset specific mode information */
 
@@ -85,8 +90,8 @@ static int et3000_saveregs(unsigned char regs[])
     et3000_unlock();
     /* save extended CRT registers */
     for (i = 0; i < 3; i++) {
-	port_out(0x23 + i, __svgalib_CRT_I);
-	regs[EXT + i] = port_in(__svgalib_CRT_D);
+	port_out(0x23 + i, CRT_I);
+	regs[EXT + i] = port_in(CRT_D);
     }
 
     /* save extended sequencer register */
@@ -99,7 +104,7 @@ static int et3000_saveregs(unsigned char regs[])
     regs[EXT + 5] = port_in(0x3cd);
 
     /* save extended attribute register */
-    port_in(__svgalib_IS1_R);		/* reset flip flop */
+    port_in(IS1_R);		/* reset flip flop */
     port_out(0x16, ATT_IW);
     regs[EXT + 6] = port_in(ATT_R);
 
@@ -125,22 +130,22 @@ static void et3000_setregs(const unsigned char regs[], int mode)
     }
 
     /* deprotect CRT register 0x25 */
-    port_out(0x11, __svgalib_CRT_I);
-    save = port_in(__svgalib_CRT_D);
-    port_out(save & 0x7F, __svgalib_CRT_D);
+    port_out(0x11, CRT_I);
+    save = port_in(CRT_D);
+    port_out(save & 0x7F, CRT_D);
 
     /* write extended CRT registers */
     for (i = 0; i < 3; i++) {
-	port_out(0x23 + i, __svgalib_CRT_I);
-	port_out(regs[EXT + i], __svgalib_CRT_D);
+	port_out(0x23 + i, CRT_I);
+	port_out(regs[EXT + i], CRT_D);
     }
 
     /* set original CRTC 0x11 */
-    port_out(0x11, __svgalib_CRT_I);
-    port_out(save, __svgalib_CRT_D);
+    port_out(0x11, CRT_I);
+    port_out(save, CRT_D);
 
     /* write extended attribute register */
-    port_in(__svgalib_IS1_R);		/* reset flip flop */
+    port_in(IS1_R);		/* reset flip flop */
     port_out(0x16, ATT_IW);
     port_out(regs[EXT + 6], ATT_IW);
 }
@@ -155,7 +160,7 @@ static int et3000_modeavailable(int mode)
 
     regs = LOOKUPMODE(et3000_modes, mode);
     if (regs == NULL || mode == GPLANE16)
-	return __svgalib_vga_driverspecs.modeavailable(mode);
+	return vga_driverspecs.modeavailable(mode);
     if (regs == DISABLE_MODE || mode <= TEXT || mode > GLASTMODE)
 	return 0;
 
@@ -190,7 +195,7 @@ static int et3000_setmode(int mode, int prv_mode)
 
     switch (et3000_modeavailable(mode)) {
     case STDVGADRV:
-	return __svgalib_vga_driverspecs.setmode(mode, prv_mode);
+	return vga_driverspecs.setmode(mode, prv_mode);
     case SVGADRV:
 	regs = LOOKUPMODE(et3000_modes, mode);
 	if (regs != NULL)
@@ -200,7 +205,7 @@ static int et3000_setmode(int mode, int prv_mode)
     }
 
     et3000_unlock();
-    __svgalib_setregs(regs);
+    __vga_setregs(regs);
     et3000_setregs(regs, mode);
     return 0;
 }
@@ -246,7 +251,7 @@ static int et3000_test(void)
 
     /* test for ET3000 clues */
     if (port_in(0x3cc) & 1)
-	base = CRT_IC;
+	base = 0x3d4;
     else
 	base = 0x3b4;
     port_out(0x1b, base);
@@ -298,14 +303,14 @@ static void et3000_setwrpage(int page)
 
 static void et3000_setdisplaystart(int address)
 {
-    outw(CRT_IC, 0x0d + ((address >> 2) & 0x00ff) * 256);	/* sa2-sa9 */
-    outw(CRT_IC, 0x0c + ((address >> 2) & 0xff00));	/* sa10-sa17 */
-    port_in(0x3da);			/* set ATC to addressing mode */
-    outb(ATT_IW, 0x13 + 0x20);	/* select ATC reg 0x13 */
-    outb(ATT_IW, (port_in(ATT_R) & 0xf0) | ((address & 3) << 1));
+    outw(0x3d4, 0x0d + ((address >> 2) & 0x00ff) * 256);	/* sa2-sa9 */
+    outw(0x3d4, 0x0c + ((address >> 2) & 0xff00));	/* sa10-sa17 */
+    inb(0x3da);			/* set ATC to addressing mode */
+    outb(0x3c0, 0x13 + 0x20);	/* select ATC reg 0x13 */
+    outb(0x3c0, (inb(0x3c1) & 0xf0) | ((address & 3) << 1));
     /* write sa0-1 to bits 1-2 */
-    outb(CRT_IC, 0x23);
-    outb(CRT_DC, (port_in(CRT_DC) & 0xfd)
+    outb(0x3d4, 0x23);
+    outb(0x3d5, (inb(0x3d5) & 0xfd)
 	 | ((address & 0x40000) >> 17));	/* write sa18 to bit 1 */
 }
 
@@ -314,13 +319,13 @@ static void et3000_setdisplaystart(int address)
 
 static void et3000_setlogicalwidth(int width)
 {
-    outw(CRT_IC, 0x13 + (width >> 3) * 256);	/* lw3-lw11 */
+    outw(0x3d4, 0x13 + (width >> 3) * 256);	/* lw3-lw11 */
 }
 
 
 /* Function table (exported) */
 
-DriverSpecs __svgalib_et3000_driverspecs =
+DriverSpecs et3000_driverspecs =
 {
     et3000_saveregs,
     et3000_setregs,
@@ -344,8 +349,7 @@ DriverSpecs __svgalib_et3000_driverspecs =
     0,				/* extset */
     0,
     0,				/* linear */
-    NULL,                       /* Accelspecs */
-    NULL,                       /* Emulation */
+    NULL			/* accelspecs */
 };
 
 
@@ -362,10 +366,7 @@ static int et3000_init(int force, int par1, int par2)
 
     if (__svgalib_driver_report)
 	printf("Using Tseng ET3000 driver (%d).\n", et3000_memory);
-    __svgalib_driverspecs = &__svgalib_et3000_driverspecs;
+    driverspecs = &et3000_driverspecs;
 
-    __svgalib_banked_mem_base=0xa0000;
-    __svgalib_banked_mem_size=0x10000;
-
-   return 0;
+    return 0;
 }
