@@ -37,14 +37,14 @@
    the documentation, a 2 meg board should be able to do an interlaced
    1280x1024x256.  I couldn't force Oak's BIOS to enter that mode.
    Could be because I have only 1 meg on board.
+
  */
 
 #include <stdio.h>
-#include <string.h>
 #include "vga.h"
 #include "libvga.h"
 #include "driver.h"
-#include <sys/types.h>
+#include <sys/mman.h>
 #include "oak.regs"
 
 #define OTI_MISC_DATA EXT+01
@@ -100,6 +100,7 @@ static int oak_chiptype;
 static int oak_memory;
 static int oak_lockreg_save;
 static unsigned char last_page = 0;
+static void *linearframebuffer;
 static unsigned char *VGAMemory_Save;
 
 static int oak_init(int, int, int);
@@ -115,7 +116,6 @@ static void oak_clearlinearmode(void);
 static void oak_setpage(int page);
 static void OAK_WriteDAC(int function);
 static void OAKSetByte(int, int);
-static void * linearframebuffer;
 
 /* Mode table */
 
@@ -140,11 +140,6 @@ static ModeTable oak_modes[] =
 
 
 
-
-
-
-
-
 };
 
 /* oak_getmodeinfo( int mode, vga_modeinfo *modeinfo)   Tell SVGALIB stuff
@@ -231,15 +226,15 @@ static void oak_setregs(const unsigned char regs[], int mode)
 	OAKSetByte(OTI87_XREADSEGMENT, regs[OTI87_XREADSEGMENT_DATA]);
 	OAKSetByte(OTI87_XWRITESEGMENT, regs[OTI87_XWRITESEGMENT_DATA]);
 
-	outb(SEQ_I, 0);		/* reset sync. */
-	junk = port_in(SEQ_D);
-	outw(SEQ_I, 0x00 + ((junk & 0xfd) << 8));
+	outb(0x3c4, 0);		/* reset sync. */
+	junk = inb(0x3c5);
+	outw(0x3c4, 0x00 + ((junk & 0xfd) << 8));
 
 	OAKSetByte(OTI87_CLOCK, regs[EXT + 8]);
 	OAKSetByte(OTI87_FIFO, regs[OTI87_FIFO_DATA]);
 	OAKSetByte(OTI87_MODESELECT, regs[OTI87_MODESELECT_DATA]);
 
-	outw(SEQ_I, 0x00 + (junk << 8));	/* set sync. */
+	outw(0x3c4, 0x00 + (junk << 8));	/* set sync. */
 
 	OAKSetByte(OTI87_XCRTC, regs[OTI87_XCRTC_DATA]);
 	OAKSetByte(OTI87_OVERFLOW, regs[EXT + 9]);
@@ -249,14 +244,14 @@ static void oak_setregs(const unsigned char regs[], int mode)
 	OAKSetByte(OTI_SEGMENT, regs[OTI_SEGMENT_DATA]);
 
 	/* doc says don't OTI-MISC unless sync. reset is off */
-	outb(SEQ_I, 0);
-	junk = port_in(SEQ_D);
-	outw(SEQ_I, 0x00 + ((junk & 0xFD) << 8));	/* now disable the timing sequencer */
+	outb(0x3c4, 0);
+	junk = inb(0x3c5);
+	outw(0x3C4, 0x00 + ((junk & 0xFD) << 8));	/* now disable the timing sequencer */
 
 	OAKSetByte(OTI_MISC, regs[OTI_MISC_DATA]);
 
 	/* put sequencer back */
-	outw(SEQ_I, 0x00 + (junk << 8));
+	outw(0x3C4, 0x00 + (junk << 8));
 
 	OAKSetByte(OTI_BCOMPAT, regs[OTI_BCOMPAT_DATA]);
 	OAKSetByte(OTI_CONFIG, regs[OTI_CONFIG_DATA]);
@@ -279,7 +274,7 @@ static int oak_modeavailable(int mode)
 
     regs = LOOKUPMODE(oak_modes, mode);
     if (regs == NULL || mode == GPLANE16) {
-	return __svgalib_vga_driverspecs.modeavailable(mode);
+	return vga_driverspecs.modeavailable(mode);
     }
     if (regs == DISABLE_MODE || mode <= TEXT || mode > GLASTMODE) {
 	return 0;
@@ -333,7 +328,7 @@ static int oak_setmode(int mode, int prv_mode)
     }
     rp = LOOKUPMODE(oak_modes, mode);
     if (rp == NULL || mode == GPLANE16)
-	return (int) (__svgalib_vga_driverspecs.setmode(mode, prv_mode));
+	return (int) (vga_driverspecs.setmode(mode, prv_mode));
     if (!oak_modeavailable(mode))
 	return 1;		/* mode not available */
 
@@ -350,13 +345,7 @@ static int oak_setmode(int mode, int prv_mode)
 	} else {
 	    regs[OTI_CONFIG_DATA] &= 0xF7;
 	}
-    } else {			/* oak_chiptype == 87 */
-	if (mode == G640x480x256) {
-	    /* Oak-87 needs this bit, Oak-67 does not stand it - MW */
-	    regs[SEQ + 1] |= 0x8;
-	}
     }
-
     if (__svgalib_infotable[mode].colors == 16) {
 
 	/* switch from 256 to 16 color mode (from XFree86) */
@@ -369,7 +358,7 @@ static int oak_setmode(int mode, int prv_mode)
 	    regs[OTI_MISC_DATA] |= 0x18;
 	}
     }
-    __svgalib_setregs(regs);
+    __vga_setregs(regs);
     oak_setregs(regs, mode);
     if ((oak_chiptype == 87) & (OTI87_OK_LINEAR == 1)) {
 	oak_setlinearmode();
@@ -391,9 +380,9 @@ static void oak_unlock(void)
 {
     int temp;
     /* Unprotect CRTC[0-7] */
-    outb(__svgalib_CRT_I, 0x11);
-    temp = port_in(__svgalib_CRT_D);
-    outb(__svgalib_CRT_D, temp & 0x7F);
+    outb(CRT_I, 0x11);
+    temp = inb(CRT_D);
+    outb(CRT_D, temp & 0x7F);
     temp = OAKGetByte(OTI_CRT_CNTL);
     OAKSetByte(OTI_CRT_CNTL, temp & 0xf0);
     oak_lockreg_save = temp;
@@ -412,9 +401,9 @@ static void oak_lock(void)
     /* don't set the i/o write test bit, though we cleared it on entry */
     OAKSetByte(OTI_CRT_CNTL, oak_lockreg_save & 0xf7);
     /* Protect CRTC[0-7] */
-    outb(__svgalib_CRT_I, 0x11);
-    temp = port_in(__svgalib_CRT_D);
-    outb(__svgalib_CRT_D, (temp & 0x7F) | 0x80);
+    outb(CRT_I, 0x11);
+    temp = inb(CRT_D);
+    outb(CRT_D, (temp & 0x7F) | 0x80);
 }
 
 /* oak_test()                                           Probe for Oak card
@@ -500,7 +489,7 @@ static void oak_setwrpage(int page)
 /* oak_setdisplaystart( int address )                   Set display address
 
  * Sets display start address.
- * First word goes into CRT_IC indices 0x0c and 0x0d
+ * First word goes into 0x3d4 indices 0x0c and 0x0d
  * If 067, bit 16 goes to OTI_OVERFLOW bit 3
  * If 077, bit 17 goes to OTI_OVERFLOW2 bit 3
  * If 087, bits 16, 17, and 18 go to OTI87_XCRTC bits 0-2
@@ -508,11 +497,11 @@ static void oak_setwrpage(int page)
 
 static void oak_setdisplaystart(int address)
 {
-    outw(CRT_IC, 0x0d + ((address >> 2) & 0x00ff) * 256);	/* sa2-sa9 */
-    outw(CRT_IC, 0x0c + ((address >> 2) & 0xff00));	/* sa10-sa17 */
-    port_in(0x3da);			/* set ATC to addressing mode */
-    outb(ATT_IW, 0x13 + 0x20);	/* select ATC reg 0x13 */
-    outb(ATT_IW, (port_in(ATT_R) & 0xf0) | ((address & 3) << 1));
+    outw(0x3d4, 0x0d + ((address >> 2) & 0x00ff) * 256);	/* sa2-sa9 */
+    outw(0x3d4, 0x0c + ((address >> 2) & 0xff00));	/* sa10-sa17 */
+    inb(0x3da);			/* set ATC to addressing mode */
+    outb(0x3c0, 0x13 + 0x20);	/* select ATC reg 0x13 */
+    outb(0x3c0, (inb(0x3c1) & 0xf0) | ((address & 3) << 1));
     /* write sa0-1 to bits 1-2 */
 
     if (oak_chiptype == 87) {
@@ -538,7 +527,7 @@ static void oak_setdisplaystart(int address)
 
 static void oak_setlogicalwidth(int width)
 {
-    outw(CRT_IC, 0x13 + (width >> 3) * 256);	/* lw3-lw11 */
+    outw(0x3d4, 0x13 + (width >> 3) * 256);	/* lw3-lw11 */
 }
 
 /* oak_init ( int force, int par1, int par2)            Initialize chipset
@@ -563,13 +552,7 @@ static int oak_init(int force, int par1, int par2)
 	printf("Using Oak driver (OTI-0%d, %dK).\n", oak_chiptype,
 	       oak_memory);
     }
-    __svgalib_driverspecs = &__svgalib_oak_driverspecs;
-
-    __svgalib_banked_mem_base=0xa0000;
-    __svgalib_banked_mem_size=0x10000;
-    __svgalib_linear_mem_base=0xe00000;
-    __svgalib_linear_mem_size=oak_memory*0x400;
-
+    driverspecs = &oak_driverspecs;
     return 1;
 }
 
@@ -622,7 +605,7 @@ static int oak_chipdetect(void)
 {
     int temp1;
 
-    temp1 = port_in(OTI_INDEX);
+    temp1 = inb(OTI_INDEX);
     temp1 &= 0xe0;
     if (temp1 == 0x40)
 	return 67;
@@ -640,7 +623,7 @@ static int oak_chipdetect(void)
     /* none of the above ... maybe the nonexistant '97 I've been 
        hearing about? */
 
-/*    printf("Oak driver: Unknown chipset (id = %2x)\n", temp1);*/
+    printf("Oak driver: Unknown chipset (id = %2x)\n", temp1);
     oak_lock();
     return 0;
 }
@@ -673,15 +656,15 @@ static void oak_setlinearmode(void)
     int temp1;
     temp1 = ((OAKGetByte(OTI87_STATUS) & 0x06) << 1) | 0xe1;
     OAKSetByte(OTI87_VIDMAP, temp1);
-/*    linearframebuffer = (unsigned char *) mmap((caddr_t) 0x40000000,
+    linearframebuffer = (unsigned char *) mmap((caddr_t) 0x40000000,
 					       oak_memory * 1024,
 					       PROT_READ | PROT_WRITE,
 					       MAP_SHARED | MAP_FIXED,
 					       __svgalib_mem_fd,
 					       0xe00000);
-*/
-    linearframebuffer=LINEAR_POINTER;
     VGAMemory_Save = __svgalib_graph_mem;
+/*      __svgalib_graph_mem = linearframebuffer; */
+/*      graph_mem = __svgalib_graph_mem; */
     __svgalib_modeinfo_linearset |= IS_LINEAR;
 }
 
@@ -697,6 +680,7 @@ static void oak_clearlinearmode(void)
     __svgalib_modeinfo_linearset ^= IS_LINEAR;
     __svgalib_graph_mem = VGAMemory_Save;
     graph_mem = VGAMemory_Save;
+    munmap((caddr_t) 0x40000000, oak_memory * 1024);
 
 }
 
@@ -709,13 +693,13 @@ static void oak_clearlinearmode(void)
 
 static void OAK_WriteDAC(int dac_value)
 {
-    port_in(DAC_REVERT);		/* reset DAC r/w pointer */
-    port_in(DAC_SC11487);		/* do this four times to set register A */
-    port_in(DAC_SC11487);
-    port_in(DAC_SC11487);
-    port_in(DAC_SC11487);
+    inb(DAC_REVERT);		/* reset DAC r/w pointer */
+    inb(DAC_SC11487);		/* do this four times to set register A */
+    inb(DAC_SC11487);
+    inb(DAC_SC11487);
+    inb(DAC_SC11487);
     outb(DAC_SC11487, dac_value);
-    port_in(DAC_REVERT);		/* and reset DAC ... */
+    inb(DAC_REVERT);		/* and reset DAC ... */
 }
 
 /* OAKSetByte ( index, value)                           Set extended register
@@ -740,12 +724,12 @@ static void OAKSetByte(int OTI_index, int OTI_value)
 static int OAKGetByte(int OTI_index)
 {
     outb(OTI_INDEX, OTI_index);
-    return port_in(OTI_R_W);
+    return inb(OTI_R_W);
 }
 
 /* Function table (exported) */
 
-DriverSpecs __svgalib_oak_driverspecs =
+DriverSpecs oak_driverspecs =
 {
     oak_saveregs,
     oak_setregs,
@@ -769,8 +753,7 @@ DriverSpecs __svgalib_oak_driverspecs =
     0,				/* extset */
     0,
     0,				/* linear */
-    NULL,                       /* Accelspecs */
-    NULL,                       /* Emulation */
+    NULL,			/* accelspecs */
 #if 0
     (int (*)()) oak_setlinearmode,
     (int (*)()) oak_clearlinearmode,
