@@ -7,8 +7,7 @@
  */
 
 /* This is the type of a basic (monitor-oriented) mode timing. */
-typedef struct _MMT_S MonitorModeTiming;
-struct _MMT_S {
+typedef struct {
     int pixelClock;		/* Pixel clock in kHz. */
     int HDisplay;		/* Horizontal Timing. */
     int HSyncStart;
@@ -19,8 +18,7 @@ struct _MMT_S {
     int VSyncEnd;
     int VTotal;
     int flags;
-    MonitorModeTiming *next;
-};
+} MonitorModeTiming;
 
 /* This is for the hardware (card)-adjusted mode timing. */
 typedef struct {
@@ -58,9 +56,6 @@ typedef struct {
 #define HADJUSTED	0x40	/* Horizontal CRTC timing adjusted. */
 #define VADJUSTED	0x80	/* Vertical CRTC timing adjusted. */
 #define USEPROGRCLOCK	0x100	/* A programmable clock is used. */
-#define TVMODE		0x200
-#define TVPAL		0x400
-#define TVNTSC		0x800 
 
 /*
  * Note: Double scan implies that each scanline is displayed twice. The
@@ -110,10 +105,6 @@ typedef struct {
 #define GREATER_1024_DIVIDE_VERT	0x4
 /* The DAC doesn't support 64K colors (5-6-5) at 16bpp, just 5-5-5. */
 #define NO_RGB16_565			0x8
-/* Card (or driver) can't do interlaced modes */
-#define NO_INTERLACE			0x10
-/* Don't have banked memory - emulated with mmap from linear memory */
-#define EMULATE_BANK			0x20
 
 /* Mode info. */
 typedef struct {
@@ -152,19 +143,10 @@ typedef struct {
  * of the card.
  */
 
-int __svgalib_getmodetiming(
+int getmodetiming(
 		     ModeTiming *,	/* Resulting mode timing. */
 		     ModeInfo *,	/* Structural mode info. */
 		     CardSpecs *	/* Card specs (dot clocks etc.). */
 );
 
-void __svgalib_addusertiming(
-		      MonitorModeTiming *
-);
-
-/* GTF constants */
-#define GTF_lockVF	1		/* Lock to vertical frequency	*/
-#define GTF_lockHF	2		/* Lock to horizontal frequency	*/
-#define GTF_lockPF	3		/* Lock to pixel clock frequency*/
-
 #endif
