@@ -1,5 +1,5 @@
-/* VGAlib version 1.2 - (c) 1993 Tommy Frandsen 		   */
-/*								   */
+/* VGAlib version 1.2 - (c) 1993 Tommy Frandsen                    */
+/*                                                                 */
 /* This library is free software; you can redistribute it and/or   */
 /* modify it without any restrictions. This library is distributed */
 /* in the hope that it will be useful, but without any warranty.   */
@@ -10,7 +10,8 @@
 #define VGA_H
 
 #ifdef __cplusplus
-extern "C" {
+extern "C"
+{
 #endif
 
 #define TEXT 	     0		/* Compatible with VGAlib v1.2 */
@@ -61,35 +62,35 @@ extern "C" {
 #define __GLASTMODE G1280x1024x16M32
 #define GLASTMODE vga_lastmodenumber()
 
-extern int vga_setmode(int mode);
-extern int vga_hasmode(int mode);
-extern int vga_setflipchar(int c);
+    extern int vga_setmode(int mode);
+    extern int vga_hasmode(int mode);
+    extern int vga_setflipchar(int c);
 
-extern int vga_clear();
-extern int vga_flip();
+    extern int vga_clear(void);
+    extern int vga_flip(void);
 
-extern int vga_getxdim();
-extern int vga_getydim();
-extern int vga_getcolors();
+    extern int vga_getxdim(void);
+    extern int vga_getydim(void);
+    extern int vga_getcolors(void);
 
-extern int vga_setpalette(int index, int red, int green, int blue);
-extern int vga_getpalette(int index, int *red, int *green, int *blue);
-extern int vga_setpalvec(int start, int num, int *pal);
-extern int vga_getpalvec(int start, int num, int *pal);
+    extern int vga_setpalette(int index, int red, int green, int blue);
+    extern int vga_getpalette(int index, int *red, int *green, int *blue);
+    extern int vga_setpalvec(int start, int num, int *pal);
+    extern int vga_getpalvec(int start, int num, int *pal);
 
-extern int vga_screenoff();
-extern int vga_screenon();
+    extern int vga_screenoff(void);
+    extern int vga_screenon(void);
 
-extern int vga_setcolor(int color);
-extern int vga_drawpixel(int x, int y);
-extern int vga_drawline(int x1, int y1, int x2, int y2);
-extern int vga_drawscanline(int line, unsigned char* colors);
-extern int vga_drawscansegment(unsigned char* colors, int x, int y, int length);
-extern int vga_getpixel(int x, int y);	/* Added. */
+    extern int vga_setcolor(int color);
+    extern int vga_drawpixel(int x, int y);
+    extern int vga_drawline(int x1, int y1, int x2, int y2);
+    extern int vga_drawscanline(int line, unsigned char *colors);
+    extern int vga_drawscansegment(unsigned char *colors, int x, int y, int length);
+    extern int vga_getpixel(int x, int y);	/* Added. */
 
-extern int vga_getch();
+    extern int vga_getch(void);
 
-extern int vga_dumpregs();
+    extern int vga_dumpregs(void);
 
 
 /* Extensions to VGAlib v1.2: */
@@ -110,9 +111,11 @@ extern int vga_dumpregs();
 #define IS_LINEAR 32		/* Linear addressing enabled. */
 #define EXT_INFO_AVAILABLE 64	/* Returned modeinfo contains valid extended fields */
 #define RGB_MISORDERED 128	/* Mach32 32bpp uses 0BGR instead of BGR0. */
+    /* As of this version 1.25 also used to signal if real RGB
+       (red first in memory) is used instead of BGR (Mach32 DAC 4) */
 #define HAVE_EXT_SET 256	/* vga_ext_set() available */
 
-typedef struct {
+    typedef struct {
 	int width;
 	int height;
 	int bytesperpixel;
@@ -132,52 +135,52 @@ typedef struct {
 				   set_displaystart */
 	char *linear_aperture;	/* points to mmap secondary mem aperture of card (NULL if unavailable) */
 	int aperture_size;	/* size of aperture in KB if size>=videomemory. 0 if unavail */
-	void (*set_aperture_page)(int page);
-				/* if aperture_size<videomemory select a memory page */
+	void (*set_aperture_page) (int page);
+	/* if aperture_size<videomemory select a memory page */
 	void *extensions;	/* points to copy of eeprom for mach32 */
-				/* depends from actual driver/chiptype.. etc. */
-} vga_modeinfo;
+	/* depends from actual driver/chiptype.. etc. */
+    } vga_modeinfo;
 
-extern vga_modeinfo *vga_getmodeinfo( int mode );
-extern int vga_getdefaultmode();
-extern int vga_getcurrentmode();
-extern int vga_getcurrentchipset();
-extern char *vga_getmodename( int mode );
-extern int vga_getmodenumber( char *name );
-extern int vga_lastmodenumber(void);
+    extern vga_modeinfo *vga_getmodeinfo(int mode);
+    extern int vga_getdefaultmode(void);
+    extern int vga_getcurrentmode(void);
+    extern int vga_getcurrentchipset(void);
+    extern char *vga_getmodename(int mode);
+    extern int vga_getmodenumber(char *name);
+    extern int vga_lastmodenumber(void);
 
-extern unsigned char *graph_mem;
-extern unsigned char *vga_getgraphmem();
+    extern unsigned char *graph_mem;
+    extern unsigned char *vga_getgraphmem(void);
 
-extern void vga_setpage( int p );
-extern void vga_setreadpage( int p );
-extern void vga_setwritepage( int p );
-extern void vga_setlogicalwidth( int w );
-extern void vga_setdisplaystart( int a );
-extern void vga_waitretrace();
-extern int vga_claimvideomemory( int n );
-extern void vga_disabledriverreport();
-extern int vga_setmodeX();
-extern int vga_init();	/* Used to return void in svgalib <= 1.12. */
-extern int vga_getmousetype();
-extern int vga_getmonitortype();
-extern void vga_setmousesupport( int s );
-extern void vga_lockvc();
-extern void vga_unlockvc();
-extern int vga_getkey();
-extern void vga_runinbackground( int s );
-extern int vga_oktowrite();
-extern void vga_copytoplanar256( unsigned char *virtualp, int pitch,
-	int voffset, int vpitch, int w, int h );
-extern void vga_copytoplanar16( unsigned char *virtualp, int pitch,
-	int voffset, int vpitch, int w, int h );
-extern void vga_copytoplane( unsigned char *virtualp, int pitch,
-	int voffset, int vpitch, int w, int h, int plane );
-extern int vga_setlinearaddressing();
-extern void vga_safety_fork(void (*shutdown_routine)(void));
+    extern void vga_setpage(int p);
+    extern void vga_setreadpage(int p);
+    extern void vga_setwritepage(int p);
+    extern void vga_setlogicalwidth(int w);
+    extern void vga_setdisplaystart(int a);
+    extern void vga_waitretrace(void);
+    extern int vga_claimvideomemory(int n);
+    extern void vga_disabledriverreport(void);
+    extern int vga_setmodeX(void);
+    extern int vga_init(void);	/* Used to return void in svgalib <= 1.12. */
+    extern int vga_getmousetype(void);
+    extern int vga_getmonitortype(void);
+    extern void vga_setmousesupport(int s);
+    extern void vga_lockvc(void);
+    extern void vga_unlockvc(void);
+    extern int vga_getkey(void);
+    extern void vga_runinbackground(int s);
+    extern int vga_oktowrite(void);
+    extern void vga_copytoplanar256(unsigned char *virtualp, int pitch,
+				  int voffset, int vpitch, int w, int h);
+    extern void vga_copytoplanar16(unsigned char *virtualp, int pitch,
+				   int voffset, int vpitch, int w, int h);
+    extern void vga_copytoplane(unsigned char *virtualp, int pitch,
+		       int voffset, int vpitch, int w, int h, int plane);
+    extern int vga_setlinearaddressing(void);
+    extern void vga_safety_fork(void (*shutdown_routine) (void));
 
 
-#ifdef EGA	/* Kernel headers may define this. */
+#ifdef EGA			/* Kernel headers may define this. */
 #undef EGA
 #endif
 
@@ -185,7 +188,7 @@ extern void vga_safety_fork(void (*shutdown_routine)(void));
 #define VGA		1
 #define ET4000		2
 #define CIRRUS		3
-#define TVGA8900	4 
+#define TVGA8900	4
 #define OAK		5
 #define EGA		6
 #define S3		7
@@ -195,7 +198,7 @@ extern void vga_safety_fork(void (*shutdown_routine)(void));
 #define ARK		11
 #define ATI		12
 
-				/* Hor. sync: */
+    /* Hor. sync: */
 #define MON640_60	0	/* 31.5 KHz (standard VGA) */
 #define MON800_56	1	/* 35.1 KHz (old SVGA) */
 #define MON1024_43I	2	/* 35.5 KHz (low-end SVGA, 8514) */
@@ -204,24 +207,24 @@ extern void vga_safety_fork(void (*shutdown_routine)(void));
 #define MON1024_70	5	/* 56.0 KHz (SVGA high frequency) */
 #define MON1024_72	6
 
-extern void vga_setchipset( int c );
-extern void vga_setchipsetandfeatures( int c, int par1, int par2 );
-extern void vga_gettextfont( void *font );
-extern void vga_puttextfont( void *font );
-extern void vga_settextmoderegs( void *regs );
-extern void vga_gettextmoderegs( void *regs );
+    extern void vga_setchipset(int c);
+    extern void vga_setchipsetandfeatures(int c, int par1, int par2);
+    extern void vga_gettextfont(void *font);
+    extern void vga_puttextfont(void *font);
+    extern void vga_settextmoderegs(void *regs);
+    extern void vga_gettextmoderegs(void *regs);
 
-extern int vga_white(); 
-extern int vga_setegacolor( int c );
-extern int vga_setrgbcolor( int r, int g, int b );
+    extern int vga_white(void);
+    extern int vga_setegacolor(int c);
+    extern int vga_setrgbcolor(int r, int g, int b);
 
-extern void vga_bitblt( int srcaddr, int destaddr, int w, int h, int pitch );
-extern void vga_imageblt( void *srcaddr, int destaddr, int w, int h, int pitch );
-extern void vga_fillblt( int destaddr, int w, int h, int pitch, int c );
-extern void vga_hlinelistblt( int ymin, int n, int *xmin, int *xmax, int pitch, int c );
-extern void vga_blitwait();
-extern int vga_ext_set(unsigned what, ...);
-extern int vga_accel(unsigned operation, ...);
+    extern void vga_bitblt(int srcaddr, int destaddr, int w, int h, int pitch);
+    extern void vga_imageblt(void *srcaddr, int destaddr, int w, int h, int pitch);
+    extern void vga_fillblt(int destaddr, int w, int h, int pitch, int c);
+    extern void vga_hlinelistblt(int ymin, int n, int *xmin, int *xmax, int pitch, int c);
+    extern void vga_blitwait(void);
+    extern int vga_ext_set(unsigned what,...);
+    extern int vga_accel(unsigned operation,...);
 
 /* Valid values for what in vga_ext_set: */
 #define VGA_EXT_AVAILABLE	0	/* supported flags */
@@ -288,7 +291,6 @@ extern int vga_accel(unsigned operation, ...);
 
 #ifdef __cplusplus
 }
+
 #endif
-
-#endif /* VGA_H */
-
+#endif				/* VGA_H */
