@@ -11,12 +11,11 @@
 #include <string.h>
 #include "vga.h"
 #include "libvga.h"
-#include "driver.h"
-#include "ppcmemset.h"
 
 int vga_clear(void)
 {
     vga_screenoff();
+
     if (MODEX)
 	goto modeX;
     switch (CM) {
@@ -24,12 +23,11 @@ int vga_clear(void)
     case G320x240x256:
     case G320x400x256:
     case G360x480x256:
-    case G400x300x256X:
       modeX:
-        
 	/* write to all planes */
-        __svgalib_outseq(0x02,0x0f);
-        
+	port_out(0x02, SEQ_I);
+	port_out(0x0F, SEQ_D);
+
 	/* clear video memory */
 	memset(GM, 0, 65536);
 	break;
@@ -41,21 +39,20 @@ int vga_clear(void)
 	    vga_setcolor(0);
 
 	    /* write to all bits */
-            __svgalib_outseq(0x08,0xff);
+	    port_out(0x08, GRA_I);
+	    port_out(0xFF, GRA_D);
 
 	default:
 	    {
 		int i;
 		int pages = (CI.ydim * CI.xbytes + 65535) >> 16;
-                if (__svgalib_modeinfo_linearset & IS_LINEAR ) {
-                    memset(LINEAR_POINTER, 0, pages<<16);
-                } else {
-                    for (i = 0; i < pages; ++i) {
-                        vga_setpage(i);
-		        /* clear video memory */
-                        memset(GM, 0, 65536);
-                    }
-                }
+
+		for (i = 0; i < pages; ++i) {
+		    vga_setpage(i);
+
+		    /* clear video memory */
+		    memset(GM, 0, 65536);
+		}
 	    }
 	    break;
 	}
@@ -63,6 +60,7 @@ int vga_clear(void)
     }
 
     vga_setcolor(15);
+
     vga_screenon();
 
     return 0;
