@@ -1,4 +1,4 @@
-
+/* VGAlib version 1.2 - (c) 1993 Tommy Frandsen                    */
 /*                                                                 */
 /* This library is free software; you can redistribute it and/or   */
 /* modify it without any restrictions. This library is distributed */
@@ -17,11 +17,9 @@
 
 #define MODENAME_LENGTH 20
 
-/* This is set by vga.c if there's a 'default_mode' line in the config */
-extern int __svgalib_default_mode;
 
 /* This one won't type an error message ... */
-int __svgalib_name2number(char *m)
+int __vga_name2number(char *m)
 {
     int i;
 
@@ -37,20 +35,19 @@ int vga_getmodenumber(char *m)
     int i;
     char s[3];
 
-    __svgalib_getchipset();		/* Do initialisation first */
-    i = __svgalib_name2number(m);
+    __vga_getchipset();		/* Do initialisation first */
+    i = __vga_name2number(m);
     if (i > 0)
 	return i;
 
     for (i = G320x200x16; i <= GLASTMODE; i++) {
 	sprintf(s, "%d", i);
-	if (strcasecmp(m, s) == 0)	/* check number */
+	if (strcmp(m, s) == 0)	/* check number */
 	    return i;
     }
-    if (strcasecmp(m, "PROMPT") == 0)
+    if (strcmp(m, "PROMPT") == 0)
 	return -1;
-
-    fprintf(stderr, "Invalid graphics mode \'%s\'.\n", m);
+    printf("Invalid graphics mode in environment variable.\n");
     return -1;
 }
 
@@ -82,39 +79,15 @@ char *
     return modename;
 }
 
-int vga_getdefaultmode(void) {
-    char *stmp = getenv("SVGALIB_DEFAULT_MODE");
-
-/* Process env var first so mode might be overridden by it. */
-    if (stmp != NULL && strcmp(stmp, "") != 0) {
-      int mode;
-      if ( (mode = vga_getmodenumber(stmp)) != -1)
-	return mode;
-    } else if (__svgalib_default_mode) {
-      return __svgalib_default_mode;
-    }
-    return 10;	/* Default */
-}
-
-/* find the mode with minimal resolution (defined as num of pixels) that
-can display x*y */
-int vga_getoptmode(int x, int y, int colors, int bytesperpixel, int c)
+int vga_getdefaultmode(void)
 {
-   int i;
-   int cur,size;
-   
-   cur=-1;
-   size=1<<24;
-   
-   for(i=0;i<GLASTMODE;i++)
-      if( vga_hasmode(i)&&
-         (infotable[i].colors==colors)&&
-         (infotable[i].bytesperpixel==bytesperpixel)&&
-         (infotable[i].xdim>=x)&&
-         (infotable[i].ydim>=y)&&
-         (infotable[i].ydim*infotable[i].xdim<size)) {
-            	size=infotable[i].ydim*infotable[i].xdim;
-                cur=i;
-      };
-   return cur;
-};
+    char *e;
+    int m;
+    e = getenv("GSVGAMODE");
+    if (e != NULL && strcmp(e, "") != 0) {
+	m = vga_getmodenumber(e);
+	if (m != -1)
+	    return m;
+    }
+    return -1;
+}
